from __future__ import absolute_import

from unittest import TestCase

from bs4 import BeautifulSoup
from sphinx_testing import with_app

from hieroglyph.tests import util


class SlideFooterTests(TestCase):

    @with_app(
        buildername='slides',
        srcdir=util.test_root,
        confoverrides={
            'slide_footer': 'TEST FOOTER',
        },
    )
    def test_footer_added_to_all_slides(self, sphinx_app, status, warning):

        sphinx_app.build()

        slide_html = BeautifulSoup(
            open(sphinx_app.builddir/'slides'/'index.html').read(),
            "html.parser",
        )
        slides = slide_html.find_all('article', class_='slide')

        # sanity check
        self.assertEqual(
            len(slides),
            3,
        )

        for slide in slides:
            self.assertTrue(
                slide.find('div', class_='slide-footer',),
            )

            self.assertEqual(
                slide.find('div', class_='slide-footer',).text,
                sphinx_app.config.slide_footer,
            )

    @with_app(
        buildername='slides',
        srcdir=util.test_root,
        confoverrides={
            'slide_footer': None,
        },
    )
    def test_footer_not_added_when_not_configured(self, sphinx_app, status, warning):

        sphinx_app.build()

        slide_html = BeautifulSoup(
            open(sphinx_app.builddir/'slides'/'index.html').read(),
            "html.parser",
        )
        slides = slide_html.find_all('article', class_='slide')

        # sanity check
        self.assertEqual(
            len(slides),
            3,
        )

        for slide in slides:
            self.assertFalse(
                slide.find('div', class_='slide-footer',),
            )



"""Writer Support for Hieroglyph Slides."""

from docutils import nodes
from sphinx.locale import _
from docutils.writers.html4css1 import HTMLTranslator as BaseTranslator
from sphinx.writers.html import HTMLTranslator

from hieroglyph import html
from hieroglyph.directives import (
    slide,
    slideconf,
)


def depart_title(self, node):

    # XXX Because we want to inject our link into the title, this is
    # largely copy-pasta'd from sphinx.html.writers.HtmlTranslator.

    close_tag = self.context[-1]

    if (self.permalink_text and self.builder.add_permalinks and
            node.parent.hasattr('ids') and node.parent['ids']):
        aname = node.parent['ids'][0]

        if close_tag.startswith('</a></h'):
            self.body.append('</a>')

        self.body.append(u'<a class="headerlink" href="#%s" ' % aname +
                         u'title="%s">%s</a>' % (
                         _('Permalink to this headline'),
                         self.permalink_text))

        self.body.append(
            u'<a class="headerlink" href="%s#%s" ' % (
                html.slide_path(self.builder),
                aname,
            ) +
            u'title="%s">%s' % (
                _('Slides'),
                self.builder.app.config.slide_html_slide_link_symbol,
            ))

        if not close_tag.startswith('</a></h'):
            self.body.append('</a>')

    BaseTranslator.depart_title(self, node)


class SlideData(object):

    def __init__(self, translator, **kwargs):

        self._translator = translator

        self.level = 0
        self.title = ''
        self.content = ''
        self.classes = []
        self.slide_number = 0
        self.id = ''

        for name, value in kwargs.items():
            setattr(self, name, value)

    def _filter_classes(self, include=None, exclude=None):

        classes = self.classes[:]
        if include is not None:
            classes = [
                c[len(include):] for c in classes
                if c.startswith(include)
            ]

        if exclude is not None:
            classes = [
                c for c in classes
                if not c.startswith(exclude)
            ]

        return classes

    def get_slide_context(self):
        """Return the context dict for rendering this slide."""

        return {
            'title': self.title,
            'level': self.level,
            'content': self.content,
            'classes': self.classes,
            'slide_classes': self._filter_classes(exclude='content-'),
            'content_classes': self._filter_classes(include='content-'),
            'slide_number': self.slide_number,
            'config': self._translator.builder.config,
            'id': self.id,
        }


class BaseSlideTranslator(HTMLTranslator):

    def __init__(self, *args, **kwargs):

        HTMLTranslator.__init__(self, *args, **kwargs)

        self.section_count = 0
        self.body_stack = []
        self.current_slide = None
        self.slide_data = []

    def push_body(self):
        """Push the current body onto the stack and create an empty one."""

        self.body_stack.append(self.body)
        self.body = []

    def pop_body(self):
        """Replace the current body with the last one pushed to the stack."""

        self.body = self.body_stack.pop()

    def visit_slideconf(self, node):
        pass

    def depart_slideconf(self, node):
        pass

    def _add_slide_number(self, slide_no):
        """Add the slide number to the output if enabled."""

        if self.builder.config.slide_numbers:
            self.body.append(
                '\n<div class="slide-no">%s</div>\n' % (slide_no,),
            )

    def _add_slide_footer(self, slide_no):
        """Add the slide footer to the output if enabled."""

        if self.builder.config.slide_footer:
            self.body.append(
                '\n<div class="slide-footer">%s</div>\n' % (
                    self.builder.config.slide_footer,
                ),
            )

    def visit_slide(self, node):

        from hieroglyph import builder

        slide_level = node.attributes.get('level', self.section_level)

        if slide_level > self.builder.config.slide_levels:
            # dummy for matching div's
            self.body.append(
                self.starttag(
                    node, 'div', CLASS='section level-%s' % slide_level)
            )
            node.tag_name = 'div'
        else:

            slide_conf = slideconf.get_conf(self.builder, node.document)
            if (builder.building_slides(self.builder.app) and
                    slide_conf['autoslides'] and
                    isinstance(node.parent, nodes.section) and
                    not getattr(node.parent, 'closed', False)):

                # we're building slides and creating slides from
                # sections; close the previous section, if needed
                self.depart_slide(node.parent)

            # don't increment section_count until we've (potentially)
            # closed the previous slide
            self.section_count += 1

            node.closed = False

            classes = node.get('classes')
            if not classes:
                classes = slide_conf['slide_classes']

            # self.body.append(
            #     self.starttag(
            #         node, 'article',
            #         CLASS='%s slide level-%s' % (
            #             ' '.join(classes),
            #             slide_level,
            #         ),
            #     )
            # )
            node.tag_name = 'article'

            slide_id = node.get('ids')
            if slide_id:
                slide_id = slide_id[0]
            else:
                slide_id = ''

            assert self.current_slide is None
            self.current_slide = SlideData(
                self,
                id=slide_id,
                level=slide_level,
                classes=classes,
                slide_number=self.section_count,
            )
            self.push_body()

    def depart_slide(self, node):

        if self.current_slide and not getattr(node, 'closed', False):

            # mark the slide closed
            node.closed = True

            # self._add_slide_footer(self.section_count)
            # self._add_slide_number(self.section_count)
            # self.body.append(
            #     '\n</%s>\n' % getattr(node, 'tag_name', 'article')
            # )

            self.current_slide.content = ''.join(self.body)
            self.pop_body()
            rendered_slide = self.builder.templates.render(
                'slide.html',
                self.current_slide.get_slide_context(),
            )
            self.body.append(rendered_slide)
            self.slide_data.append(self.current_slide)
            self.current_slide = None

    def visit_title(self, node):

        self.push_body()

        if (isinstance(node.parent, slide) or
                node.parent.attributes.get('include-as-slide', False)):
            slide_level = node.parent.attributes.get(
                'level',
                self.section_level)
            level = max(
                slide_level + self.initial_header_level - 1,
                1,
            )
            self.current_slide.level = level

            # tag = 'h%s' % level
            # self.body.append(self.starttag(node, tag, ''))
            # self.context.append('</%s>\n' % tag)

        if self.current_slide and isinstance(node.parent, (nodes.section, slide)):
            self.current_slide.title = node.astext().strip()
        else:
            HTMLTranslator.visit_title(self, node)


    def depart_title(self, node):

        if self.current_slide and isinstance(node.parent, (nodes.section, slide)):
            self.current_slide.title = ''.join(self.body)
            self.pop_body()
        else:
            HTMLTranslator.depart_title(self, node)
            title = ''.join(self.body)
            self.pop_body()
            self.body.append(title)

    def visit_block_quote(self, node):
        quote_slide_tags = ['paragraph', 'attribution']

        # see if this looks like a quote slide
        if (len(node.children) <= 2 and
            [c.tagname for c in node.children] == quote_slide_tags[:len(node.children)]):

            # process this as a quote slide

            # first child must be a paragraph, process it as a <q> element
            p = node.children[0]
            self.body.append(self.starttag(node, 'q'))
            for text_item in p:
                text_item.walkabout(self)
                self.body.append('</q>\n')

            # optional second child must be an attribution, processing as a <div>
            # following the <q>
            if len(node.children) > 1:
                attr = node.children[1]

                self.body.append(self.starttag(attr, 'div', CLASS="author"))
                for text_item in attr:
                    text_item.walkabout(self)
                    self.body.append('</div>\n')

            # skip all normal processing
            raise nodes.SkipNode

        else:
            return HTMLTranslator.visit_block_quote(self, node)


class SlideTranslator(BaseSlideTranslator):

    def visit_section(self, node):

        # XXX: We're actually removing content that's not in slide
        # nodes with autoslides is false, so it's not clear that we
        # even need this guard.
        if (slideconf.get_conf(self.builder, node.document)['autoslides'] or
                node.attributes.get('include-as-slide', False)):

            self.section_level += 1
            return self.visit_slide(node)

    def depart_section(self, node):

        if (slideconf.get_conf(self.builder, node.document)['autoslides'] or
                node.attributes.get('include-as-slide', False)):

            if self.section_level > self.builder.config.slide_levels:
                self.body.append('</div>')
            else:
                self.depart_slide(node)

            self.section_level -= 1

    def depart_title(self, node):

        if node.parent.hasattr('ids') and node.parent['ids']:
            aname = node.parent['ids'][0]

            if self.builder.app.config.slide_link_to_html:
                self.body.append(
                    u'<a class="headerlink" href="%s#%s" ' % (
                        html.html_path(self.builder),
                        aname,
                    ) +
                    u'title="%s">%s</a>' % (
                        _('View HTML'),
                        self.builder.app.config.slide_html_slide_link_symbol,
                    ))

        BaseSlideTranslator.depart_title(self, node)

    def visit_start_of_file(self, node):
        previous = node.parent
        if isinstance(previous, nodes.compound):
            # step up one more level
            previous = previous.parent

        self.depart_slide(previous)
        self.section_level -= 1

        BaseSlideTranslator.visit_start_of_file(self, node)


class SingleFileSlideTranslator(SlideTranslator):

    def visit_compound(self, node):
        if not 'toctree-wrapper' in node['classes']:
            SlideTranslator.visit_compound(self, node)

    def depart_compound(self, node):
        if not 'toctree-wrapper' in node['classes']:
            SlideTranslator.depart_compound(self, node)



from unittest import TestCase

from docutils import nodes
from mock import patch
from sphinx import jinja2glue
from sphinx_testing import TestApp

from hieroglyph.tests import util

from hieroglyph.builder import SlideBuilder
from hieroglyph.writer import (
    SlideData,
    BaseSlideTranslator,
    SlideTranslator,
)


class SlideTranslationTests(TestCase):

    def setUp(self):

        self.app = TestApp(
            buildername='slides',
            copy_srcdir_to_tmpdir=True,
            srcdir=util.test_root,
        )
        self.builder = self.app.builder
        self.document = util.make_document(
            'testing',
            """\
Slide ``Title``
---------------

* Bullet 1
* Bullet 2

""",
        )
        self.translator = BaseSlideTranslator(
            self.builder,
            self.document,
        )

    def test_push_body(self):

        self.translator.body = [1, 2, 3]

        self.translator.push_body()

        self.assertEqual(self.translator.body, [])
        self.assertEqual(self.translator.body_stack, [[1, 2, 3]])

        self.translator.body.append('foo')
        self.translator.push_body()
        self.assertEqual(
            self.translator.body_stack,
            [
                [1, 2, 3, ],
                ['foo', ],
            ],
        )

    def test_pop_body(self):

        self.translator.body.append('a')
        self.translator.push_body()

        self.translator.body.append('1')
        self.translator.push_body()

        self.assertEqual(
            self.translator.body_stack,
            [
                ['a'],
                ['1'],
            ],
        )
        self.assertEqual(self.translator.body, [])

        self.translator.pop_body()
        self.assertEqual(
            self.translator.body_stack,
            [
                ['a'],
            ],
        )
        self.assertEqual(self.translator.body, ['1'])

    def test_visit_slide_creates_new_slide_data(self):

        # sanity checks
        self.assertIsNone(self.translator.current_slide)
        self.assertIsInstance(self.document[0], nodes.section)

        # visit the slide section
        self.translator.visit_slide(self.document[0])

        # verify the Slide was created
        self.assertIsNotNone(self.translator.current_slide)
        self.assertIsInstance(self.translator.current_slide, SlideData)
        self.assertEqual(
            self.translator.current_slide.level,
            self.document[0].attributes.get(
                'level',
                self.translator.section_level,
            ),
        )

    def test_section_classes_added_to_slidedata(self):

        self.document[0].set_class('fancy')

        # visit the slide section
        self.translator.visit_slide(self.document[0])

        self.assertEqual(
            self.translator.current_slide.classes,
            ['fancy'],
        )

    def test_prefixed_classes_added_to_slidedata_context_classes(self):

        self.document[0].set_class('fancy')
        self.document[0].set_class('content-inner')

        # visit the slide section
        self.translator.visit_slide(self.document[0])

        self.assertEqual(
            self.translator.current_slide.get_slide_context()['classes'],
            ['fancy', 'content-inner'],
        )
        self.assertEqual(
            self.translator.current_slide.get_slide_context()['slide_classes'],
            ['fancy', ],
        )
        self.assertEqual(
            self.translator.current_slide.get_slide_context()['content_classes'],
            ['inner'],
        )

    def test_depart_slide_clears_current_slide(self):

        # visit the slide section
        self.translator.visit_slide(self.document[0])
        self.assertIsNotNone(self.translator.current_slide)

        self.translator.depart_slide(self.document[0])
        self.assertIsNone(self.translator.current_slide)

    def test_visit_title_in_slide_sets_slide_title(self):

        # visit the slide section
        self.translator.visit_slide(self.document[0])

        # visit the title
        self.translator.visit_title(self.document[0][0])

        self.assertEqual(
            self.document[0][0].astext(),
            self.translator.current_slide.title,
        )

    def test_depart_slide_sets_slide_content(self):
        pass

    def test_slide_data_get_context(self):

        slide = SlideData(
            self.translator,
            title='My Pretty Slide',
            id='my-pretty-slide',
            level=1,
        )

        self.assertEqual(
            slide.get_slide_context(),
            {
                'title': 'My Pretty Slide',
                'level': 1,
                'content': '',
                'classes': [],
                'slide_classes': [],
                'content_classes': [],
                'id': 'my-pretty-slide',
                'slide_number': 0,
                'config': self.translator.builder.config,
            },
        )

    @patch.object(jinja2glue.BuiltinTemplateLoader, 'render')
    def test_depart_slide_calls_template_render(self, render_mock):

        self.translator.visit_slide(self.document[0])
        self.assertIsNotNone(self.translator.current_slide)
        current_slide = self.translator.current_slide

        self.translator.depart_slide(self.document[0])
        self.assertIsNone(self.translator.current_slide)

        render_mock.assert_called_once_with(
            'slide.html',
            current_slide.get_slide_context(),
        )

    @patch.object(
        jinja2glue.BuiltinTemplateLoader,
        'render',
        return_value='** SLIDE **',
    )
    def test_rendered_template_added_to_body(self, render_mock):

        self.translator.visit_slide(self.document[0])
        self.translator.depart_slide(self.document[0])

        self.assertIsNone(self.translator.current_slide)
        self.assertEqual(
            self.translator.body[-1],
            '** SLIDE **',
        )

    @patch.object(
        jinja2glue.BuiltinTemplateLoader,
        'render',
        return_value='** SLIDE **',
    )
    def test_only_rendered_template_added(self, render_mock):

        self.translator.visit_section = self.translator.visit_slide
        self.translator.depart_section = self.translator.depart_slide
        self.document.walkabout(self.translator)

        self.assertEqual(
            self.translator.body,
            ['** SLIDE **'],
        )

    def test_section_id_added_to_current_slide(self):
        self.document[0].set_class('fancy')

        # visit the slide section
        self.translator.visit_slide(self.document[0])

        self.assertEqual(
            self.translator.current_slide.id,
            'slide-title',
        )

    def test_inline_markup_in_title(self):

        self.translator.visit_section = self.translator.visit_slide
        self.translator.depart_section = self.translator.depart_slide
        self.document.walkabout(self.translator)

        self.assertIn(
            str(self.translator.slide_data[-1].title),
            [
                # Sphinx 1.1, 1.2
                'Slide <tt class="docutils literal">'
                '<span class="pre">Title</span></tt>',

                # Sphinx 1.3
                'Slide <code class="docutils literal">'
                '<span class="pre">Title</span></code>',

                # Sphinx 1.7 @Python3.7
                'Slide <code class="docutils literal notranslate">'
                '<span class="pre">Title</span></code>'

            ],
        )

    def test_non_section_titles_rendered_normally(self):
        document = util.make_document(
            'testing',
            """\
Section Title
-------------

Some Text

.. note:: Take note!

Another paragraph

""",
        )
        translator = SlideTranslator(
            self.builder,
            document,
        )

        document.walkabout(translator)

        self.assertEqual(
            translator.body,
            [
                u'\n<article class="slide level-1" id="section-title">\n\n'
                '<h1>Section Title</h1>\n\n'
                '<p>Some Text</p>\n'
                '<div class="admonition note">\n'
                '<p class="first admonition-title">Note</p>\n'
                '<p class="last">Take note!</p>\n'
                '</div>\n'
                '<p>Another paragraph</p>'
                '\n\n\n\n\n</article>',
            ],
        )

    def test_slide_titles(self):
        document = util.make_document(
            'testing',
            """\
.. slide:: Slide Title

   Slide Content

""",
        )
        translator = SlideTranslator(
            self.builder,
            document,
        )

        document.walkabout(translator)

        self.assertEqual(
            translator.body,
            [
                u'\n<article class="admonition-slide-title slide level-1">\n\n'
                '<h1>Slide Title</h1>\n\n'
                '<p>Slide Content</p>\n\n\n\n\n</article>',
            ],
        )


class QuoteSlideTests(TestCase):

    def setUp(self):

        self.app = TestApp(
            buildername='slides',
            copy_srcdir_to_tmpdir=True,
            srcdir=util.test_root,
        )
        self.builder = self.app.builder

    def test_rst_quote_makes_quote_slide(self):
        document = util.make_document(
            'quoted',
            """\
.. slide:: Quotes
 :level: 2

   reStructuredText quotes are automatically converted

   -- The Sign Painter

""",
        )
        translator = SlideTranslator(
            self.builder,
            document,
        )

        document.walkabout(translator)

        self.assertEqual(
            translator.body,
            [
                u'\n<article class="admonition-quotes slide level-2">\n\n'
                '<h2>Quotes</h2>\n\n'
                '<q>\n'
                'reStructuredText quotes are automatically converted</q>\n'
                '<div class="author">\n'
                'The Sign Painter</div>'
                '\n\n\n\n\n</article>',
            ],
        )

    def test_unattributed_rst_quote_makes_quote_slide(self):
        document = util.make_document(
            'quoted',
            """\
.. slide:: Quotes
 :level: 2

   reStructuredText quotes are automatically converted

""",
        )
        translator = SlideTranslator(
            self.builder,
            document,
        )

        document.walkabout(translator)

        self.assertEqual(
            translator.body,
            [
                u'\n<article class="admonition-quotes slide level-2">\n\n'
                '<h2>Quotes</h2>\n\n'
                '<q>\n'
                'reStructuredText quotes are automatically converted</q>\n'
                '\n\n\n\n</article>',
            ],
        )

    def test_rst_quote_processes_normally_with_extra_content(self):
        document = util.make_document(
            'quoted',
            """\
.. slide:: Indented RST
 :level: 2

   This text is over indented.

   As is this text.

   They look like quotes but they're not.

""",
        )
        translator = SlideTranslator(
            self.builder,
            document,
        )

        document.walkabout(translator)

        self.assertEqual(
            translator.body,
            [
                u'\n<article class="admonition-indented-rst slide level-2">\n\n'
                '<h2>Indented RST</h2>\n\n'
                '<blockquote>\n'
                '<div><p>This text is over indented.</p>\n'
                '<p>As is this text.</p>\n'
                '<p>They look like quotes but they\'re not.</p>\n'
                '</div></blockquote>\n'
                '\n\n\n\n</article>',
            ],
        )



import docutils.frontend
import docutils.parsers.rst
import docutils.writers.html4css1
import docutils.utils
from sphinx_testing.path import path
from sphinx_testing import with_app as with_sphinx_testing


test_root = path(__file__).parent.joinpath('root').abspath()
test_roots = path(__file__).parent.joinpath('roots').abspath()


def with_app(*args, **kwargs):
    """Decorator for passing a test Sphinx app to a function.

    Extends sphinx_testing's version by defaulting to a base test directory
    if none is specified. The test directory will be copied to a temporary
    directory before calling the function.

    """

    if 'srcdir' not in kwargs and 'create_new_srcdir' not in kwargs:
        kwargs['srcdir'] = test_root
        kwargs['copy_srcdir_to_tmpdir'] = True

    return with_sphinx_testing(*args, **kwargs)


def make_document(source_name, contents):
    """Parse ```contents``` into a docutils document."""

    parser = docutils.parsers.rst.Parser()
    document = docutils.utils.new_document(
        source_name,
        docutils.frontend.OptionParser(
            components=(
                docutils.parsers.rst.Parser,
                docutils.writers.html4css1.Writer,
            ),
        ).get_default_values(),
    )

    parser.parse(contents, document)

    return document



#!/usr/bin/env python

import os
from setuptools import setup, find_packages
import versioneer

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()
NEWS = open(os.path.join(here, 'NEWS.txt')).read()


install_requires = [
    "setuptools",
    "Sphinx >= 2.0",
]


setup(name='hieroglyph',
      version=versioneer.get_version(),
      cmdclass=versioneer.get_cmdclass(),
      description=("Generate HTML presentations from plain text "
                   "sources with all the power of Sphinx."),
      long_description=README + '\n\n' + NEWS,
      classifiers=[
        'License :: OSI Approved :: BSD License',
        'Topic :: Documentation',
        'Topic :: Text Processing',
        "Programming Language :: Python :: 3",
      ],
      keywords='',
      author='Nathan Yergler',
      author_email='nathan@yergler.net',
      url='https://github.com/nyergler/hieroglyph',
      license='BSD',
      packages=find_packages('src'),
      package_dir={'': 'src'},
      include_package_data=True,
      zip_safe=False,
      install_requires=install_requires,
      entry_points={
          'console_scripts': [
              'hieroglyph=hieroglyph.quickstart:main',
              'hieroglyph-quickstart=hieroglyph.quickstart:quickstart',
          ],
          'hieroglyph.theme': [
              'slides=hieroglyph.themes:SLIDES',
              'single-level=hieroglyph.themes:SINGLE_LEVEL',
              'slides2=hieroglyph.themes:SLIDES2',
          ],
      },
      test_suite='hieroglyph.tests',
      tests_require=[
          'beautifulsoup4',
          'mock',
          'sphinx-testing',
      ],
      )



#!/usr/bin/env python

import codecs
import re
import jinja2
import markdown

def process_slides():
  with codecs.open('../../presentation-output.html', 'w', encoding='utf8') as outfile:
    md = codecs.open('slides.md', encoding='utf8').read()
    md_slides = md.split('\n---\n')
    print('Compiled %s slides.' % len(md_slides))

    slides = []
    # Process each slide separately.
    for md_slide in md_slides:
      slide = {}
      sections = md_slide.split('\n\n')
      # Extract metadata at the beginning of the slide (look for key: value)
      # pairs.
      metadata_section = sections[0]
      metadata = parse_metadata(metadata_section)
      slide.update(metadata)
      remainder_index = metadata and 1 or 0
      # Get the content from the rest of the slide.
      content_section = '\n\n'.join(sections[remainder_index:])
      html = markdown.markdown(content_section)
      slide['content'] = postprocess_html(html, metadata)

      slides.append(slide)

    template = jinja2.Template(open('base.html').read())

    outfile.write(template.render(locals()))

def parse_metadata(section):
  """Given the first part of a slide, returns metadata associated with it."""
  metadata = {}
  metadata_lines = section.split('\n')
  for line in metadata_lines:
    colon_index = line.find(':')
    if colon_index != -1:
      key = line[:colon_index].strip()
      val = line[colon_index + 1:].strip()
      metadata[key] = val

  return metadata

def postprocess_html(html, metadata):
  """Returns processed HTML to fit into the slide template format."""
  if metadata.get('build_lists') and metadata['build_lists'] == 'true':
    html = html.replace('<ul>', '<ul class="build">')
    html = html.replace('<ol>', '<ol class="build">')
  return html

if __name__ == '__main__':
  process_slides()
